##############################
Rigol DG800 waveform generator
##############################

.. autoclass:: pymeasure.instruments.rigol.DG800
    :members:
    :show-inheritance:
.. autoclass:: pymeasure.instruments.rigol.rigol_dg800.VoltageChannel
    :members:
    :show-inheritance: